responses

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 13, 2025 License: MIT Imports: 1 Imported by: 1

Documentation

Index

Constants

const (
	// ClassSuccess specifies that the DSN is reporting a positive delivery
	// action.  Detail sub-codes may provide notification of
	// transformations required for delivery.
	ClassSuccess = 2
	// ClassTransientFailure - a persistent transient failure is one in which the message as
	// sent is valid, but persistence of some temporary condition has
	// caused abandonment or delay of attempts to send the message.
	// If this code accompanies a delivery failure report, sending in
	// the future may be successful.
	ClassTransientFailure = 4
	// ClassPermanentFailure - a permanent failure is one which is not likely to be resolved
	// by resending the message in the current form.  Some change to
	// the message or the destination must be made for successful
	// delivery.
	ClassPermanentFailure = 5
)
const (
	OtherStatus                             = ".0.0"
	OtherAddressStatus                      = ".1.0"
	BadDestinationMailboxAddress            = ".1.1"
	BadDestinationSystemAddress             = ".1.2"
	BadDestinationMailboxAddressSyntax      = ".1.3"
	DestinationMailboxAddressAmbiguous      = ".1.4"
	DestinationMailboxAddressValid          = ".1.5"
	MailboxHasMoved                         = ".1.6"
	BadSendersMailboxAddressSyntax          = ".1.7"
	BadSendersSystemAddress                 = ".1.8"
	OtherOrUndefinedMailboxStatus           = ".2.0"
	MailboxDisabled                         = ".2.1"
	MailboxFull                             = ".2.2"
	MessageLengthExceedsAdministrativeLimit = ".2.3"
	MailingListExpansionProblem             = ".2.4"
	OtherOrUndefinedMailSystemStatus        = ".3.0"
	MailSystemFull                          = ".3.1"
	SystemNotAcceptingNetworkMessages       = ".3.2"
	SystemNotCapableOfSelectedFeatures      = ".3.3"
	MessageTooBigForSystem                  = ".3.4"
	OtherOrUndefinedNetworkOrRoutingStatus  = ".4.0"
	NoAnswerFromHost                        = ".4.1"
	BadConnection                           = ".4.2"
	RoutingServerFailure                    = ".4.3"
	UnableToRoute                           = ".4.4"
	NetworkCongestion                       = ".4.5"
	RoutingLoopDetected                     = ".4.6"
	DeliveryTimeExpired                     = ".4.7"
	OtherOrUndefinedProtocolStatus          = ".5.0"
	InvalidCommand                          = ".5.1"
	SyntaxError                             = ".5.2"
	TooManyRecipients                       = ".5.3"
	InvalidCommandArguments                 = ".5.4"
	WrongProtocolVersion                    = ".5.5"
	OtherOrUndefinedMediaError              = ".6.0"
	MediaNotSupported                       = ".6.1"
	ConversionRequiredAndProhibited         = ".6.2"
	ConversionRequiredButNotSupported       = ".6.3"
	ConversionWithLossPerformed             = ".6.4"
	ConversionFailed                        = ".6.5"
)

DefaultMap contains defined default codes (RfC 3463)

const SP = " "

space char

Variables

var ErrorRelayDenied = &response{
	enhancedCode: BadDestinationMailboxAddress,
	basicCode:    454,
	class:        ClassTransientFailure,
	comment:      "GetError: Relay access denied:",
}
var ErrorShutdown = &response{
	enhancedCode: OtherOrUndefinedMailSystemStatus,
	basicCode:    421,
	class:        ClassTransientFailure,
	comment:      "Server is shutting down. Please try again later. Sayonara!",
}
var ErrorTooManyRecipients = &response{
	enhancedCode: TooManyRecipients,
	basicCode:    452,
	class:        ClassTransientFailure,
	comment:      "Too many recipients",
}
var FailBackendNotRunning = &response{
	enhancedCode: OtherOrUndefinedProtocolStatus,
	basicCode:    554,
	class:        ClassPermanentFailure,
	comment:      "Transaction failed - backend not running",
}
var FailBackendTimeout = &response{
	enhancedCode: OtherOrUndefinedProtocolStatus,
	basicCode:    554,
	class:        ClassPermanentFailure,
	comment:      "GetError: transaction timeout",
}
var FailBackendTransaction = &response{
	enhancedCode: OtherOrUndefinedProtocolStatus,
	basicCode:    554,
	class:        ClassPermanentFailure,
	comment:      "GetError:",
}
var FailCommandNotImplemented = &response{
	enhancedCode: InvalidCommand,
	basicCode:    502,
	class:        ClassPermanentFailure,
	comment:      "Command not implemented",
}
var FailDomainTooLong = &response{
	enhancedCode: InvalidCommandArguments,
	basicCode:    550,
	class:        ClassPermanentFailure,
	comment:      "Domain cannot exceed 255 characters",
}
var FailInvalidAddress = &response{
	enhancedCode: InvalidCommandArguments,
	basicCode:    501,
	class:        ClassPermanentFailure,
	comment:      "Invalid address",
}
var FailLineTooLong = &response{
	enhancedCode: InvalidCommand,
	basicCode:    554,
	class:        ClassPermanentFailure,
	comment:      "Line too long.",
}
var FailLocalPartTooLong = &response{
	enhancedCode: InvalidCommandArguments,
	basicCode:    550,
	class:        ClassPermanentFailure,
	comment:      "Local part too long, cannot exceed 64 characters",
}
var FailMailCmd = &response{
	enhancedCode: BadDestinationMailboxAddress,
	basicCode:    550,
	class:        ClassPermanentFailure,
	comment:      "User unknown in local recipient table",
}
var FailMaxUnrecognizedCmd = &response{
	enhancedCode: InvalidCommand,
	basicCode:    554,
	class:        ClassPermanentFailure,
	comment:      "Too many unrecognized commands",
}
var FailMessageSizeExceeded = &response{
	enhancedCode: OtherOrUndefinedNetworkOrRoutingStatus,
	basicCode:    552,
	class:        ClassPermanentFailure,
	comment:      "GetError:",
}
var FailNestedMailCmd = &response{
	enhancedCode: InvalidCommand,
	basicCode:    503,
	class:        ClassPermanentFailure,
	comment:      "GetError: nested MAIL command",
}
var FailNoRecipientsDataCmd = &response{
	enhancedCode: InvalidCommand,
	basicCode:    503,
	class:        ClassPermanentFailure,
	comment:      "GetError: No recipients",
}
var FailNoSenderDataCmd = &response{
	enhancedCode: InvalidCommand,
	basicCode:    503,
	class:        ClassPermanentFailure,
	comment:      "GetError: No sender",
}
var FailPathTooLong = &response{
	enhancedCode: InvalidCommandArguments,
	basicCode:    550,
	class:        ClassPermanentFailure,
	comment:      "Path too long",
}
var FailRcptCmd = &response{
	enhancedCode: BadDestinationMailboxAddress,
	basicCode:    550,
	class:        ClassPermanentFailure,
	comment:      "User unknown in local recipient table",
}
var FailReadErrorDataCmd = &response{
	enhancedCode: OtherOrUndefinedMailSystemStatus,
	basicCode:    451,
	class:        ClassTransientFailure,
	comment:      "GetError:",
}
var FailReadLimitExceededDataCmd = &response{
	enhancedCode: MessageLengthExceedsAdministrativeLimit,
	basicCode:    550,
	class:        ClassPermanentFailure,
	comment:      "GetError:",
}
var FailSyntaxError = &response{
	enhancedCode: SyntaxError,
	basicCode:    550,
	class:        ClassPermanentFailure,
	comment:      "Syntax error",
}
var FailUnrecognizedCmd = &response{
	enhancedCode: InvalidCommand,
	basicCode:    554,
	class:        ClassPermanentFailure,
	comment:      "Unrecognized command",
}
var RejectedRcptCmd = &response{
	enhancedCode: InvalidCommandArguments,
	basicCode:    553,
	class:        ClassPermanentFailure,
	comment:      "Recipient address rejected: Access denied",
}
var RejectedSenderMailCmd = &response{
	enhancedCode: InvalidCommandArguments,
	basicCode:    553,
	class:        ClassPermanentFailure,
	comment:      "Sender address rejected: Access denied",
}
var SuccessDataCmd = &response{
	basicCode: 354,
	comment:   "354 Enter message, ending with '.' on a line by itself",
}
var SuccessMailCmd = &response{
	enhancedCode: OtherAddressStatus,
	class:        ClassSuccess,
}
var SuccessMessageAccepted = &response{
	enhancedCode: OtherStatus,
	basicCode:    250,
	class:        ClassSuccess,
	comment:      "Message accepted",
}
var SuccessMessageQueued = &response{
	enhancedCode: OtherStatus,
	basicCode:    250,
	class:        ClassSuccess,
	comment:      "OK: queued",
}
var SuccessNoopCmd = &response{
	enhancedCode: OtherStatus,
	class:        ClassSuccess,
}
var SuccessQuitCmd = &response{
	enhancedCode: OtherStatus,
	basicCode:    221,
	class:        ClassSuccess,
	comment:      "Bye",
}
var SuccessRcptCmd = &response{
	enhancedCode: DestinationMailboxAddressValid,
	class:        ClassSuccess,
}
var SuccessResetCmd = SuccessMailCmd
var SuccessStartTLSCmd = &response{
	enhancedCode: OtherStatus,
	basicCode:    220,
	class:        ClassSuccess,
	comment:      "Ready to start TLS",
}
var SuccessVerifyCmd = &response{
	enhancedCode: OtherOrUndefinedProtocolStatus,
	basicCode:    252,
	class:        ClassSuccess,
	comment:      "Cannot verify user",
}

Functions

This section is empty.

Types

type EnhancedStatusCode

type EnhancedStatusCode struct {
	Class             class
	SubjectDetailCode subjectDetail
}

EnhancedStatus are the ones that look like 2.1.0

func (EnhancedStatusCode) String

func (e EnhancedStatusCode) String() string

String returns a string representation of EnhancedStatus

Jump to